==> haskell-record-dot-preprocessor-0.2.15-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-dot-preprocessor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-dot-preprocessor
version:              0.2.15
visibility:           public
id:                   record-dot-preprocessor-0.2.15-LTBkvPvszRl8GqLO00sr7X
key:                  record-dot-preprocessor-0.2.15-LTBkvPvszRl8GqLO00sr7X
license:              BSD-3-Clause
copyright:            Neil Mitchell 2018-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:
    https://github.com/ndmitchell/record-dot-preprocessor#readme

synopsis:             Preprocessor to allow record.field syntax
description:
    In almost every programming language @a.b@ will get the @b@ field from the @a@ data type, and many different data types can have a @b@ field.
    The reason this feature is ubiquitous is because it'\''s /useful/.
    The @record-dot-preprocessor@ brings this feature to Haskell - see the README for full details.

category:             Development
abi:                  d7f30a52d7c315e646deeac0483cb0c7
exposed:              True
exposed-modules:      RecordDotPreprocessor RecordDotPreprocessor.Lib
hidden-modules:       Compat Edit Lexer Paren
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.15

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.15

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-dot-preprocessor
hs-libraries:         HSrecord-dot-preprocessor-0.2.15-LTBkvPvszRl8GqLO00sr7X
depends:
    base-4.15.1.0 extra-1.7.12-KMMam5dihF88hEFtHKrXtJ ghc-9.0.2
    uniplate-1.6.13-JhMn8rTzhWZKjdRaHcdHSs

haddock-interfaces:
    /usr/share/doc/haskell-record-dot-preprocessor/html/record-dot-preprocessor.haddock

haddock-html:         /usr/share/doc/haskell-record-dot-preprocessor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-record-dot-preprocessor-0.2.16-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-dot-preprocessor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-dot-preprocessor
version:              0.2.16
visibility:           public
id:                   record-dot-preprocessor-0.2.16-77hKRrUZb2vHQTHDDP4B3k
key:                  record-dot-preprocessor-0.2.16-77hKRrUZb2vHQTHDDP4B3k
license:              BSD-3-Clause
copyright:            Neil Mitchell 2018-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:
    https://github.com/ndmitchell/record-dot-preprocessor#readme

synopsis:             Preprocessor to allow record.field syntax
description:
    In almost every programming language @a.b@ will get the @b@ field from the @a@ data type, and many different data types can have a @b@ field.
    The reason this feature is ubiquitous is because it'\''s /useful/.
    The @record-dot-preprocessor@ brings this feature to Haskell - see the README for full details.

category:             Development
abi:                  5c71d4dfb5ca774e9e928e5969abcf37
exposed:              True
exposed-modules:      RecordDotPreprocessor RecordDotPreprocessor.Lib
hidden-modules:       Compat Edit Lexer Paren
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.16

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.16

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-dot-preprocessor
hs-libraries:         HSrecord-dot-preprocessor-0.2.16-77hKRrUZb2vHQTHDDP4B3k
depends:
    base-4.15.1.0 extra-1.7.13-FJzM8Owo9xhE12DNAJGBro ghc-9.0.2
    uniplate-1.6.13-7q1GFxogbGhHRtvV0a8oPm

haddock-interfaces:
    /usr/share/doc/haskell-record-dot-preprocessor/html/record-dot-preprocessor.haddock

haddock-html:         /usr/share/doc/haskell-record-dot-preprocessor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
